@@ -49,7 +49,7 @@ def get_ruuvi_data():
         logging.info("Apending name for " + ruuvi_data_point)
         ruuvi_data[ruuvi_data_point]["name"] = ruuvi_tags[ruuvi_data_point]["name"]
         ruuvi_data[ruuvi_data_point]["temperature_calibrated"] = (
-            ruuvi_data_point["temperature"]
+            ruuvi_data[ruuvi_data_point]["temperature"]
             + ruuvi_tags[ruuvi_data_point["mac"]]["temperatureOffset"]
         )
 
@@ -124,12 +124,12 @@ async def full(update: Update, context: ContextTypes.DEFAULT_TYPE):
 
 async def temperature(update: Update, context: ContextTypes.DEFAULT_TYPE):
 
-    # Get the data from sqlite database
+    # Get the data from sqlite database for all sensors in settings
     conn = sqlite3.connect("dbdata/temperature.sqlite")
     c = conn.cursor()
-    c.execute("SELECT * FROM ruuvi ORDER BY datetime DESC LIMIT 1")
-    data = c.fetchone()
-    text = " ".join(map(str, data))
+    c.execute("SELECT * FROM ruuvi ORDER BY datetime DESC LIMIT 1 where name in (?)", [r['name'] for r in SETTINGS['ruuvitags']])
+    data = c.fetchall()
+    text = json.dumps(data, indent=4, sort_keys=True)
 
     await context.bot.send_message(chat_id=update.effective_chat.id, text=text)
 
